@@ -2,8 +2,10 @@ package input
 
 import (
 	"fmt"
+
 	"os"
 
+	"github.com/charmbracelet/bubbles/key"
 	tea "github.com/charmbracelet/bubbletea"
 	"github.com/charmbracelet/huh"
 	"github.com/charmbracelet/lipgloss"
@@ -23,11 +25,15 @@ func (o Options) Run() error {
 
 	theme := huh.ThemeCharm()
 	theme.Focused.Base = lipgloss.NewStyle()
-	// theme.Focused.TextInput.Cursor = o.CursorStyle.ToLipgloss()
+	theme.Focused.TextInput.Cursor = o.CursorStyle.ToLipgloss()
 	theme.Focused.TextInput.Placeholder = o.PlaceholderStyle.ToLipgloss()
 	theme.Focused.TextInput.Prompt = o.PromptStyle.ToLipgloss()
 	theme.Focused.Title = o.HeaderStyle.ToLipgloss()
 
+	// Keep input keymap backwards compatible
+	keymap := huh.NewDefaultKeyMap()
+	keymap.Quit = key.NewBinding(key.WithKeys("ctrl+c", "esc"))
+
 	var echoMode huh.EchoMode
 
 	if o.Password {
@@ -50,6 +56,8 @@ func (o Options) Run() error {
 		WithShowHelp(false).
 		WithWidth(o.Width).
 		WithTheme(theme).
+		WithKeyMap(keymap).
+		WithShowHelp(o.ShowHelp).
 		WithProgramOptions(tea.WithOutput(os.Stderr)).
 		Run()
 
